==> vue-sb-components-2.1.41.tgz: package/components/progress-circular/progress-circular.js <==
import "./progress-circular.css";
import { defineComponent as t, openBlock as r, createElementBlock as s, mergeProps as a, createElementVNode as o, normalizeStyle as i, toDisplayString as c, createCommentVNode as n, pushScopeId as l, popScopeId as p } from "vue";
import { _ as d } from "../../_plugin-vue_export-helper-dad06003.js";
const u = t({
  props: {
    color: {
      default: "accent",
      type: String
    },
    indeterminate: {
      required: !1,
      type: Boolean
    },
    percentage: {
      required: !1,
      type: Boolean
    },
    progress: {
      required: !1,
      type: Number
    },
    size: {
      default: 40,
      type: Number
    }
  },
  name: "sb-progress-circular",
  computed: {
    getCircularStyle() {
      return typeof this.progress < "u" ? [
        "stroke-dasharray: 126.92",
        `stroke-dashoffset: ${(100 - this.progress) * 1.2692}`
      ] : [];
    }
  }
});
const f = (e) => (l("data-v-9c9eac72"), e = e(), p(), e), g = {
  class: "progress-circular-value",
  viewBox: "22 22 44 44"
}, y = /* @__PURE__ */ f(() => /* @__PURE__ */ o("circle", {
  class: "bg",
  cx: "44",
  cy: "44",
  fill: "none",
  r: "20.2",
  "stroke-width": "3"
}, null, -1)), m = {
  key: 0,
  class: "progress-circular-value-percentage"
};
function _(e, h, v, S, $, k) {
  return r(), s("div", a({
    class: ["progress-circular", {
      [e.color]: !!e.color,
      indeterminate: e.indeterminate || typeof e.progress > "u"
    }],
    style: [`height: ${e.size}px`, `width: ${e.size}px`]
  }, { ...e.$attrs }), [
    (r(), s("svg", g, [
      o("circle", {
        cx: "44",
        cy: "44",
        fill: "none",
        r: "20.2",
        "stroke-width": "3",
        style: i(e.getCircularStyle)
      }, null, 4),
      y
    ])),
    e.percentage ? (r(), s("div", m, c(typeof e.progress < "u" ? e.progress : 100) + "% ", 1)) : n("", !0)
  ], 16);
}
const B = /* @__PURE__ */ d(u, [["render", _], ["__scopeId", "data-v-9c9eac72"]]);
export {
  B as default
};

==> vue-sb-components-2.4.31.tgz: package/components/progress-circular/progress-circular.js <==
import "./progress-circular.css";
import { defineComponent as t, openBlock as r, createElementBlock as s, mergeProps as a, createElementVNode as o, normalizeStyle as c, toDisplayString as i, createCommentVNode as n, pushScopeId as l, popScopeId as p } from "vue";
import { _ as d } from "../../_plugin-vue_export-helper-dad06003.js";
const u = t({
  props: {
    color: {
      default: "accent",
      type: String
    },
    indeterminate: {
      required: !1,
      type: Boolean
    },
    percentage: {
      required: !1,
      type: Boolean
    },
    progress: {
      required: !1,
      type: Number
    },
    size: {
      default: 40,
      type: Number
    }
  },
  name: "sb-progress-circular",
  computed: {
    getCircularStyle() {
      return typeof this.progress < "u" ? [
        "stroke-dasharray: 126.92",
        `stroke-dashoffset: ${(100 - this.progress) * 1.2692}`
      ] : [];
    }
  }
});
const f = (e) => (l("data-v-9c9eac72"), e = e(), p(), e), g = {
  class: "progress-circular-value",
  viewBox: "22 22 44 44"
}, y = /* @__PURE__ */ f(() => /* @__PURE__ */ o("circle", {
  class: "bg",
  cx: "44",
  cy: "44",
  fill: "none",
  r: "20.2",
  "stroke-width": "3"
}, null, -1)), m = {
  key: 0,
  class: "progress-circular-value-percentage"
};
function _(e, h, v, S, $, k) {
  return r(), s("div", a({
    class: ["progress-circular", {
      [e.color]: !!e.color,
      indeterminate: e.indeterminate || typeof e.progress > "u"
    }],
    style: [`height: ${e.size}px`, `width: ${e.size}px`]
  }, { ...e.$attrs }), [
    (r(), s("svg", g, [
      o("circle", {
        cx: "44",
        cy: "44",
        fill: "none",
        r: "20.2",
        "stroke-width": "3",
        style: c(e.getCircularStyle)
      }, null, 4),
      y
    ])),
    e.percentage ? (r(), s("div", m, i(typeof e.progress < "u" ? e.progress : 100) + "% ", 1)) : n("", !0)
  ], 16);
}
const B = /* @__PURE__ */ d(u, [["render", _], ["__scopeId", "data-v-9c9eac72"]]);
export {
  B as default
};
